Exception: R2::Errors::Error
- Inherits:
-
StandardError
- Object
- StandardError
- R2::Errors::Error
- Defined in:
- lib/r2/errors.rb
Overview
Base error of the project.
All domain errors inherit from this class, allowing consumers to catch the generic error when they do not need to distinguish the cause, or a specific error when they do.
Direct Known Subclasses
BucketNotFoundError, ConfigurationError, FileNotFoundError, InvalidFileError, NetworkError, PermissionError, StorageError